#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-8dtzE3Aqwrq6kqUFJF75sz
key:                  gitit-0.16-8dtzE3Aqwrq6kqUFJF75sz
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  a14a1e2bc3aa2de51094d723bbf756df
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-8dtzE3Aqwrq6kqUFJF75sz
depends:
    HStringTemplate-0.8.8-3NDBM2ESHRY6cbNJY1ke7w
    HTTP-4000.5.0-Av3ciR8KWaeB01lIoYcRTc
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-GWc1LmCE0o9Bpe9MYCbSNj base-4.18.2.1
    base64-bytestring-1.2.1.0-8gB06GrihcB6Sq9DkPfsbE
    blaze-html-0.9.2.0-4qcHHmfvG54aNNisHVOdd bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-2gfZrFweyVzJN9zYjl5h8I
    feed-1.3.2.1-3qeU4UcKeSV6nKluxF2KqZ filepath-1.4.300.1
    filestore-0.6.5.1-JWfjfNIh2Y2IbbmerhoOtd ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-IvYZDFcIlpjJ9QjOegOs4Z
    hoauth2-2.14.0-6eYKAffyEgp6ZQJWnq7FGl
    hslogger-1.3.2.0-FjC7kUyqAxlAjx3sqxpwig
    http-client-tls-0.3.6.4-AnHGLSahOg9HVl4h6a2CCE
    http-conduit-2.3.9.1-IhIEGxcJ0jxNTiAgdkscf
    json-0.11-2f9Sdjm2rDq2Kkupj9YP3T mtl-2.3.1
    network-3.1.4.0-8EWNGK0wrm0Kwyfl1vrVL3
    network-bsd-2.8.1.0-Lf6BxW8fonDFY10s94JkQU
    network-uri-2.6.4.2-GaZ2e74kZTJHR0YFZY0APg
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-CvAEie2oy7M42TGhXKiP0b
    pandoc-3.6-6KHT06bbZov9229p5LHOuH
    pandoc-types-1.23.1.1-3REcbxewk9BFym45HoSd4W parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-J8W47WuTchP2SADTtbNvax
    recaptcha-0.1.0.4-H7KJNpC6rBEXDqTuKsuN
    safe-0.3.21-CIaFHJkUkim9etNPztXZPj
    skylighting-0.14.5-91ZtaisqS155UFXVg6Xo4J
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl syb-0.7.3-58j9w6VktxOJyTIsnWy4XC
    tagsoup-0.14.8-4iX1XTv3C8eHQBXYHkuGCW
    temporary-1.3-2H1UQnxEoYo405QWjo3iMT text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-4SGrj0HZCrpuDnPqug9Ua
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-9w5gGF1NPYRd1ESjCy9ko xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-KdI4iCjp0f03nRfNLv8Hk3
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-3blSylkbKJ5KXO4OZtCROV
    zlib-0.7.1.0-5H6r3qMV1iE2lgCYaQ5cZ

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

